@@ -1,11 +1,13 @@
 from typing import List
 
+
 import designer
+# from designer import GLOBAL_DIRECTOR
 import pygame
 
 
 class Director:
-    def __init__(self, width=800, height=600, background_color=(255, 255, 255), fps=50):
+    def __init__(self, width=800, height=600, background_color=(255, 255, 255), fps = 50):
         """
         Initializes the Director that will control the game state.
 
@@ -31,6 +33,7 @@ class Director:
         self.all_game_objects = pygame.sprite.LayeredDirty()
         self.groups = []
 
+
     def start(self):
         """
         Starts Pygame main game loop. Checks for events and DirtySprite updates. Handles animations.
@@ -42,6 +45,7 @@ class Director:
         self.screen = pygame.display.set_mode(self.window_size)
         self.screen.fill(self.bkgr_color)
 
+
         time = 0
         while self.running:
             pygame.time.Clock().tick(self.fps)
@@ -56,8 +60,6 @@ class Director:
             self.all_game_objects.update()
             rects = self.all_game_objects.draw(self.screen)
             pygame.display.update(rects)
-        pygame.display.quit()
-        pygame.quit()
 
     def add(self, *images):
         """
@@ -71,6 +73,7 @@ class Director:
         for image in images:
             self.all_game_objects.add(image)
 
+
     def add_group(self, *groups):
         """
         Adds group of DirtySprites to Director's group collection.
@@ -120,7 +123,6 @@ def set_window_color(color):
     designer.GLOBAL_DIRECTOR.screen.fill(color)
     designer.GLOBAL_DIRECTOR.background.fill(color)
 
-
 def set_window_size(width, height):
     """
     Set size of window in pixels.
